==> mingw-w64-i686-pastix-6.2.1-3-any.pkg.tar.zst: mingw32/include/pastix/config.h <==
/**
 *
 * @file pastix/config.h.in
 *
 * PaStiX configuration parameters
 *
 * @copyright 2016-2021 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
 *                      Univ. Bordeaux. All rights reserved.
 *
 * @version 6.2.1
 * @author Pierre Ramet
 * @author Mathieu Faverge
 * @author Gregoire Pichon
 * @author Tony Delarue
 * @author Nolan Bredel
 * @author Tom Moenne-Loccoz
 * @date 2021-06-29
 *
 **/
#ifndef _pastix_config_h_
#define _pastix_config_h_

#define PASTIX_VERSION_MAJOR 6
#define PASTIX_VERSION_MINOR 2
#define PASTIX_VERSION_MICRO 1

#define PASTIX_WITH_FORTRAN
/* #undef PASTIX_WITH_MPI */
/* #undef PASTIX_WITH_CUDA */
/* #undef PASTIX_WITH_EZTRACE */

/* system */
/* #undef HAVE_SCHED_SETAFFINITY */
/* #undef HAVE_CLOCK_GETTIME */
/* #define HAVE_ASPRINTF */
/* #define HAVE_VASPRINTF */
#define HAVE_ATOMIC_GCC_32_BUILTINS
#define HAVE_ATOMIC_GCC_64_BUILTINS
/* #undef HAVE_ATOMIC_GCC_128_BUILTINS */
/* #undef HAVE_ATOMIC_XLC_32_BUILTINS */
/* #undef HAVE_ATOMIC_XLC_64_BUILTINS */
/* #undef HAVE_ATOMIC_MIPOSPRO_32_BUILTINS */
/* #undef HAVE_ATOMIC_MIPOSPRO_64_BUILTINS */
/* #undef HAVE_ATOMIC_SUN_32 */
/* #undef HAVE_ATOMIC_SUN_64 */
#define HAVE_STDARG_H
#define HAVE_UNISTD_H
#define HAVE_VA_COPY
/* #undef HAVE_UNDERSCORE_VA_COPY */
#define HAVE_GETOPT_LONG
/* #undef HAVE_GETRUSAGE */
#define HAVE_GETOPT_H
#define HAVE_ERRNO_H
#define HAVE_STDDEF_H
#define HAVE_LIMITS_H
#define HAVE_STRING_H
#define HAVE_COMPLEX_H
#define HAVE_FALLTHROUGH
/* #undef HAVE_GETLINE */
/* #undef HAVE_MKDTEMP */

/* Architecture */
/* #undef PASTIX_ARCH_X86 */
#define PASTIX_ARCH_X86_64
/* #undef PASTIX_ARCH_PPC */
/* #undef PASTIX_OS_MACOS */

/* Optional packages */
#define HAVE_HWLOC

/* Ordering options */
#define PASTIX_ORDERING_SCOTCH
#define PASTIX_ORDERING_METIS
/* #undef PASTIX_ORDERING_PTSCOTCH */

#define PASTIX_ORDERING_FIX_SEED
/* #undef PASTIX_ORDERING_SCOTCH_MT */

/* Symbolic factorization options */
/* #undef PASTIX_SYMBOL_DUMP_SYMBMTX */
/* #undef PASTIX_ORDER_DRAW_LASTSEP */

/* Analyze options */
/* #undef PASTIX_BLEND_GENTRACE */
#define PASTIX_BLEND_DEEPEST_DISTRIB
/* #undef PASTIX_BLEND_PROPMAP_2STEPS */
/* #undef PASTIX_BLEND_FANIN_FR */

/* #undef FORGET_PARTITION */
/* #undef COMPACT_SMX */

/* Numerical factorization options */
/* #undef PASTIX_NUMFACT_DUMP_SOLVER */
/* #undef PASTIX_SUPERNODE_STATS */

/* Scheduling options */
/* #undef PASTIX_WITH_PARSEC */
#define PASTIX_WITH_STARPU
/* #undef PASTIX_STARPU_HETEROPRIO */

/* Models */
/* #undef PASTIX_GENERATE_MODEL */

/* #undef PASTIX_CUDA_FERMI */

/* #undef PASTIX_THREAD_COMM */

/* Debug */
/* #undef PASTIX_DEBUG_GRAPH */
/* #undef PASTIX_DEBUG_ORDERING */
/* #undef PASTIX_DEBUG_SYMBOL */
/* #undef PASTIX_DEBUG_BLEND */
/* #undef PASTIX_DEBUG_DUMP_COEFTAB */
/* #undef PASTIX_DEBUG_FACTO */
/* #undef PASTIX_DEBUG_SOLVE */
/* #undef PASTIX_DEBUG_PARSEC */
/* #undef PASTIX_DEBUG_LR */
/* #undef PASTIX_DEBUG_LR_NANCHECK */
/* #undef PASTIX_DEBUG_GMRES */
/* #undef PASTIX_DEBUG_EXIT_ON_SIGSEGV */
/* #undef PASTIX_DEBUG_MPI */

/* Datatypes used */
/* #undef PASTIX_INT64 */

#if defined(HAVE_FALLTHROUGH)
#define pastix_attr_fallthrough __attribute__((fallthrough))
#else
#define pastix_attr_fallthrough do {} while(0)
#endif

#if defined(WIN32) || defined(_WIN32)
#define PASTIX_OS_WINDOWS 1
#endif

/*
 * BEGIN_C_DECLS should be used at the beginning of your declarations,
 * so that C++ compilers don't mangle their names.  Use END_C_DECLS at
 * the end of C declarations.
 */
#undef BEGIN_C_DECLS
#undef END_C_DECLS
#if defined(c_plusplus) || defined(__cplusplus)
# define BEGIN_C_DECLS extern "C" {
# define END_C_DECLS }
#else
#define BEGIN_C_DECLS          /* empty */
#define END_C_DECLS            /* empty */
#endif

#endif /* _pastix_config_h_ */

==> mingw-w64-i686-pastix-6.2.2-2-any.pkg.tar.zst: mingw32/include/pastix/config.h <==
/**
 *
 * @file pastix/config.h.in
 *
 * PaStiX configuration parameters
 *
 * @copyright 2016-2022 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
 *                      Univ. Bordeaux. All rights reserved.
 *
 * @version 6.2.1
 * @author Pierre Ramet
 * @author Mathieu Faverge
 * @author Gregoire Pichon
 * @author Tony Delarue
 * @author Nolan Bredel
 * @author Tom Moenne-Loccoz
 * @date 2021-06-29
 *
 **/
#ifndef _pastix_config_h_
#define _pastix_config_h_

#define PASTIX_VERSION_MAJOR 6
#define PASTIX_VERSION_MINOR 2
#define PASTIX_VERSION_MICRO 2

#define PASTIX_WITH_FORTRAN
/* #undef PASTIX_WITH_MPI */
/* #undef PASTIX_WITH_CUDA */
/* #undef PASTIX_WITH_EZTRACE */

/* system */
/* #undef HAVE_SCHED_SETAFFINITY */
/* #undef HAVE_CLOCK_GETTIME */
/* #define HAVE_ASPRINTF */
/* #define HAVE_VASPRINTF */
#define HAVE_ATOMIC_GCC_32_BUILTINS
#define HAVE_ATOMIC_GCC_64_BUILTINS
/* #undef HAVE_ATOMIC_GCC_128_BUILTINS */
/* #undef HAVE_ATOMIC_XLC_32_BUILTINS */
/* #undef HAVE_ATOMIC_XLC_64_BUILTINS */
/* #undef HAVE_ATOMIC_MIPOSPRO_32_BUILTINS */
/* #undef HAVE_ATOMIC_MIPOSPRO_64_BUILTINS */
/* #undef HAVE_ATOMIC_SUN_32 */
/* #undef HAVE_ATOMIC_SUN_64 */
#define HAVE_STDARG_H
#define HAVE_UNISTD_H
#define HAVE_VA_COPY
/* #undef HAVE_UNDERSCORE_VA_COPY */
#define HAVE_GETOPT_LONG
/* #undef HAVE_GETRUSAGE */
#define HAVE_GETOPT_H
#define HAVE_ERRNO_H
#define HAVE_STDDEF_H
#define HAVE_LIMITS_H
#define HAVE_STRING_H
#define HAVE_COMPLEX_H
#define HAVE_FALLTHROUGH
/* #undef HAVE_GETLINE */
/* #undef HAVE_MKDTEMP */

/* Architecture */
/* #undef PASTIX_ARCH_X86 */
#define PASTIX_ARCH_X86_64
/* #undef PASTIX_ARCH_PPC */
/* #undef PASTIX_OS_MACOS */

/* Optional packages */
#define HAVE_HWLOC

/* Ordering options */
#define PASTIX_ORDERING_SCOTCH
#define PASTIX_ORDERING_METIS
/* #undef PASTIX_ORDERING_PTSCOTCH */

#define PASTIX_ORDERING_FIX_SEED
#define PASTIX_ORDERING_SCOTCH_MT

/* Symbolic factorization options */
/* #undef PASTIX_SYMBOL_DUMP_SYMBMTX */
/* #undef PASTIX_ORDER_DRAW_LASTSEP */

/* Analyze options */
/* #undef PASTIX_BLEND_GENTRACE */
#define PASTIX_BLEND_DEEPEST_DISTRIB
/* #undef PASTIX_BLEND_PROPMAP_2STEPS */
/* #undef PASTIX_BLEND_FANIN_FR */

/* #undef FORGET_PARTITION */
/* #undef COMPACT_SMX */

/* Numerical factorization options */
/* #undef PASTIX_NUMFACT_DUMP_SOLVER */
/* #undef PASTIX_SUPERNODE_STATS */

/* Scheduling options */
/* #undef PASTIX_WITH_PARSEC */
#define PASTIX_WITH_STARPU
/* #undef PASTIX_STARPU_HETEROPRIO */

/* Models */
/* #undef PASTIX_GENERATE_MODEL */

/* #undef PASTIX_CUDA_FERMI */

/* #undef PASTIX_THREAD_COMM */

/* Debug */
/* #undef PASTIX_DEBUG_GRAPH */
/* #undef PASTIX_DEBUG_ORDERING */
/* #undef PASTIX_DEBUG_SYMBOL */
/* #undef PASTIX_DEBUG_BLEND */
/* #undef PASTIX_DEBUG_DUMP_COEFTAB */
/* #undef PASTIX_DEBUG_FACTO */
/* #undef PASTIX_DEBUG_SOLVE */
/* #undef PASTIX_DEBUG_PARSEC */
/* #undef PASTIX_DEBUG_LR */
/* #undef PASTIX_DEBUG_LR_NANCHECK */
/* #undef PASTIX_DEBUG_GMRES */
/* #undef PASTIX_DEBUG_EXIT_ON_SIGSEGV */
/* #undef PASTIX_DEBUG_MPI */

/* Datatypes used */
/* #undef PASTIX_INT64 */

#if defined(HAVE_FALLTHROUGH)
#define pastix_attr_fallthrough __attribute__((fallthrough))
#else
#define pastix_attr_fallthrough do {} while(0)
#endif

#if defined(WIN32) || defined(_WIN32)
#define PASTIX_OS_WINDOWS 1
#endif

/*
 * BEGIN_C_DECLS should be used at the beginning of your declarations,
 * so that C++ compilers don't mangle their names.  Use END_C_DECLS at
 * the end of C declarations.
 */
#undef BEGIN_C_DECLS
#undef END_C_DECLS
#if defined(c_plusplus) || defined(__cplusplus)
# define BEGIN_C_DECLS extern "C" {
# define END_C_DECLS }
#else
#define BEGIN_C_DECLS          /* empty */
#define END_C_DECLS            /* empty */
#endif

#endif /* _pastix_config_h_ */
